Index: include/v8.h |
diff --git a/include/v8.h b/include/v8.h |
index 11fccdf023999ff3c3a8acf425c669be29cae54c..311ad434de8516dff174558f15dfe8ae45ad8179 100644 |
--- a/include/v8.h |
+++ b/include/v8.h |
@@ -2425,10 +2425,20 @@ class V8EXPORT ArrayBuffer : public Object { |
} |
/** |
* Free the memory pointed to |data|. That memory is guaranteed to be |
* previously allocated by |Allocate|. |
*/ |
- virtual void Free(void* data) = 0; |
+ virtual void Free(void* data, size_t length) { |
+ // Override with call to |Free(void*)| for compatibility |
+ // with legacy version. |
+ Free(data); |
+ } |
+ |
+ /** |
+ * Deprecated. Never called directly by V8. |
+ * For compatibility with legacy version of this interface. |
+ */ |
+ virtual void Free(void* data); |
}; |
/** |
@@ -2425,10 +2425,20 @@ class V8EXPORT ArrayBuffer : public Object { |
} |
/** |
- * Free the memory pointed to |data|. That memory is guaranteed to be |
- * previously allocated by |Allocate|. |
+ * Free the memory block of size |length|, pointed to by |data|. |
+ * That memory is guaranteed to be previously allocated by |Allocate|. |
*/ |